@@ -23,8 +23,6 @@ def needed_TAs(event):
 
   if "laboration" in event.name or "Laboration" in event.name:
     num_TAs = round(num_TAs * 1.5)
-  elif "Övning" in event.name and event.weekday() in [3, 4]:
-    num_TAs = 1
 
   return num_TAs
   
